@@ -1003,7 +1003,8 @@ class Account(AccountMixin(), ActivePeriodMixin, tree(), ModelSQL, ModelView):
         'reconcile', 'deferral', 'party_required',
         'general_ledger_balance', 'taxes']
 
-    @fields.depends('parent', *__on_change_parent_fields)
+    @fields.depends('parent', *(__on_change_parent_fields
+            + ['_parent_parent.%s' % f for f in __on_change_parent_fields]))
     def on_change_parent(self):
         if not self.parent:
             return
