@@ -994,8 +994,7 @@ class Line(ModelSQL, ModelView):
 
         # Use LEFT JOIN to allow database optimization
         # if no joined table is used in the where clause.
-        return ((table.state != 'draft')
-            & table.move.in_(move
+        return (table.move.in_(move
                 .join(period, 'LEFT', condition=move.period == period.id)
                 .join(fiscalyear, 'LEFT',
                     condition=period.fiscalyear == fiscalyear.id)
@@ -1039,7 +1038,7 @@ class Line(ModelSQL, ModelView):
             journal_period, = journal_periods
             if journal_period.state == 'close':
                 raise AccessError(
-                    gettext('account.msg_modify_line_closed_period',
+                    gettext('account.msg_modify_line_closed_journal_period',
                         journal_period=journal_period.rec_name))
         else:
             JournalPeriod.create([{
@@ -1148,6 +1147,7 @@ class Line(ModelSQL, ModelView):
             default = default.copy()
         default.setdefault('move', None)
         default.setdefault('reconciliation', None)
+        default.setdefault('reconciliations_delegated', [])
         return super(Line, cls).copy(lines, default=default)
 
     @classmethod
@@ -1832,8 +1832,9 @@ class GroupLines(Wizard):
             if line.account.reconcile:
                 to_reconcile[line.account].append(line)
 
-        balance_line.move = move
-        balance_line.save()
+        if balance_line:
+            balance_line.move = move
+            balance_line.save()
 
         for lines in to_reconcile.values():
             Line.reconcile(lines, delegate_to=balance_line)
@@ -1912,11 +1913,11 @@ class GroupLines(Wizard):
                     maturity_dates[line.account], line.maturity_date)
             else:
                 maturity_dates[line.account] = line.maturity_date
-            line = self._counterpart_line(line)
-            accounts[line.account] += line.debit - line.credit
-            if line.amount_second_currency:
-                amount_second_currency += line.amount_second_currency
-            counterpart_lines.append(line)
+            cline = self._counterpart_line(line)
+            accounts[cline.account] += cline.debit - cline.credit
+            if cline.amount_second_currency:
+                amount_second_currency += cline.amount_second_currency
+            counterpart_lines.append(cline)
         move.lines = counterpart_lines
 
         balance_line = None
@@ -1946,7 +1947,7 @@ class GroupLines(Wizard):
                 balance_line.second_currency = grouping['second_currency']
                 balance_line.amount_second_currency = (
                     -amount_second_currency)
-        balance_line.maturity_date = maturity_dates[balance_line.account]
+            balance_line.maturity_date = maturity_dates[balance_line.account]
         return move, balance_line
 
     def _counterpart_line(self, line):
